
import { useMemo } from "react";

import useMediaQuery from '@mui/material/useMediaQuery';
import startCase from "lodash/startCase";

import { NuskinThemeProvider } from "../components";
import { palette as defaultPalette } from "../themes/genome-foundation";
import { Divider } from "@mui/material";

import { createNuskinTheme } from "..";

export const nuskinThemeTitleStyle = {
    display: "flex", 
    alignItems: "center",
    justifyContent: "center"
}

const themeBoxStyles = {
    width: "150px",
    height: "150px",
    borderRadius: "10px",
    border: "1px solid black",
}

export default function ThemeBuilder() {
    const prefersDarkMode = useMediaQuery('(prefers-color-scheme: dark)');

    const appTheme = useMemo(() => {
        return createNuskinTheme(defaultPalette, prefersDarkMode);
    }, [prefersDarkMode]);

    return (
        <NuskinThemeProvider cacheKey="nuskin-foundation-ui" appTheme={appTheme} isSSR>
            <div style={{ background: "#FFF" }}>
                <h2 style={nuskinThemeTitleStyle}>Nuskin-Color-Theme</h2>
                {
                    Object.entries(defaultPalette)?.map((color) => {
                        return (
                            <div style={{marginLeft: 200}} key={color[0]}>
                                <h2>{startCase(color[0])}</h2>
                                <div style={{display: "flex", gap: "10px"}}>
                                    <div>
                                        <div style={{...themeBoxStyles,background: color[1]?.main}}/>
                                        <p>{color[1]?.main}</p>
                                    </div>
                                    {
                                        Object.entries(color[1]?.buttonState || {})?.map((colorVariety)=> {
                                            if(typeof colorVariety[1] === 'string'){
                                                return (
                                                    <div  key={colorVariety[0]}>
                                                        <div style={{
                                                            ...themeBoxStyles,
                                                            background: colorVariety[1] || "black"
                                                        }}/>
                                                        <p style={{marginTop: "15px"}}> {colorVariety[1] || ""}</p>
                                                    </div>
                                                )
                                            }
                                            else {
                                                return null
                                            }
                                        
                                        })
                                    }
                                </div>
                                <Divider />
                            </div>
                        )
                    })
                }
            </div>
        </NuskinThemeProvider>
    );
    
}