import { createTheme } from "@mui/material";

import { palette as defaultPalette } from "../themes/genome-foundation/";
export * from "./button-utils";
import { ColorKeys, Colors } from "../themes/types";

export const generatePalette = (colors: Colors, prefersDarkMode = false) => {
    const colorKeys = Object.keys(colors) as ColorKeys[];
    const paletteColors = colorKeys.reduce((result, paletteName) => {
        if (prefersDarkMode) {
            const colorObject = colors[paletteName];
            const darkMode = colorObject?.darkMode;
            if (darkMode) {
                result[paletteName] = darkMode;
            }
        }
        return result;
    }, {} as Colors);
    return paletteColors;
};

export const createNuskinTheme = (palette: Colors = defaultPalette, prefersDarkMode?: boolean) => {
    const muiTheme = createTheme({ palette })
    return {
        ...muiTheme,
        palette: {
            ...muiTheme.palette,
            ...generatePalette(palette, prefersDarkMode),
        }
    };
}